@@ -1342,7 +1342,7 @@ def main(argv):                                            # ||:fnc:||
             ah = AdHoc()
             source = ah.compileFile(file_)
         else:
-            source = AdHoc.read_source(file_)
+            file_, source = AdHoc.std_source_param(file_)
 
         # implode
         if _parameters.implode:
