@@ -34,7 +34,7 @@ Options
 
   -h, --help            display this help message
 
-Without any options, the script does that the documentation say.
+Without any options, the script does what the documentation says.
 
 Output is the same for uncompiled and compiled script.
 """
@@ -499,13 +499,16 @@ try:
 # @|:uc_code_beg:|>
 except ImportError:
     try:
+        import rt_adhoc
         from rt_adhoc import RtAdHoc
 # @|:uc_code_end:|>
 
 # --------------------------------------------------
 # @|:uc_descr_beg:|>
 #
-# Let the script continue, even if :class:`RtAdHoc` is not available::
+# Let the script continue, even if :class:`RtAdHoc` is not available:
+#
+#     ::
 #
 # @|:uc_descr_out:|>
 # @|:uc_descr_end:|>
